This directory includes scripts, palettes, and offsets for procedurally constructing and recoloring some of the LPC Pirate assets. If you are just looking to use the assets, you don't need this folder---download the main `lpc-pirates-vX.X.zip` file from https://opengameart.org/content/lpc-pirates . Credits are also there. This directory is to show how the generate certain types of repetitive assets (e.g. hats, neckwear, belts, etc.) and recolors more quickly. 

## How to use

1. Download and install [`lpctools`](https://opengameart.org/content/lpc-pirates) and its dependencies
2. If you used [`conda`](https://docs.conda.io/projects/conda/en/latest/index.html) as recommended, make sure you have [`activate`d](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html#activating-an-environment) the conda environment where `lpctools` is installed (your command prompt should start with `(lpctools)`, or the name of the environment)
3. Run `bash build.sh` from this directory.
4. The generated assets will be copied, by default, in a _sibling_ directory to this one, called `lpc-pirates`

## How it works

Skip to `build.sh` for details. Essentially:
- for most assets, we start with a minimal set of frames, build a complete spritesheet by applying some offsets (defined in `reference_points_*.png`) to those frames and optionally masking certain parts of the frame (defined in `masks_*.png`; e.g. for hats, when the front arm partially covers the head in the shoot animation, so that part of the hat is deleted). 
- then we generate a programmatic set of recolors by mapping the palette with which the assets were originally drawn to a bunch of new palettes. These mappings are defined in `_palettes/*.json`. 
- finally, we copy around the output files/folders to create the same file structure as the [Universal LPC Spritesheet Generator](https://github.com/sanderfrenken/Universal-LPC-Spritesheet-Character-Generator)

Notes: 

- `accessories/masks_*` and `accessories/reference_points_*` differ from the corresponding files in `hats`. The former should be used for objects on the torso that would be covered by the arms, while the latter should be used for hair, headgear, etc. (which, if it extended down, might partially cover the shoulders/arms). 
- The `reference_points_*.png` files work like this: the top-left-most non-transparent pixel will be used to mark where the _center_ of the source image is placed, in each frame. For hats, that point is chosen, for convenience, to be the top-left-most pixel of the head. This is why the hats are not perfectly centered in the frame. (In `reference_points_*.png`, all pixels other than the top-left-most one in each frame are ignored. The line just shows where the character's head goes, but you could just as well use a single point)

## Q&A

- Why are there separate black and brown hats?
	+ because that's how I drew them originally. you could convert them all to the brown palette if you 
		wanted, I was just too lazy. plus for the most part, the black hats had different colored trim. 
		by passing both the fabric-from-black and trim-hats palette mappings and using 
		`--combine product`, all combinations of palettes from the two mappings are produced
- Why are there separate `lpc-fabric-from-{brown,red,black}.json`?
	+ Same reason as for the hats. The destination palettes are all the same, just the source palette is different. This violates the DRY principle but 
- Why is the folder structure weird and kind of inconsistent?
	+ It's more or less arbitrary and could probably be cleaner... 
		* Ultimately, I wanted to be able to copy the output files (from `../lpc-pirates`) directly into the [Universal LPC Spritesheet Generator](https://github.com/sanderfrenken/Universal-LPC-Spritesheet-Character-Generator), so I moved/copied the files as appropriate to re-create the folder structure of that. but I didn't want too many sub-folders in here so I just put the assets into groups according to how they needed to be processed
		* accessories: need to generate male- and female- versions of the full sheets; those go into `accessories/_intermediate` and get recolored from there, then the recolors are copied to the generator
		* hats: build the hats directly in the 
		* male-only `clothes` and `jackets`: lpctools likes to create recolors of `file.png` as `file/palette1.png`, `file/palette2.png`, etc., so the male-only `clothes/` are organized like that, then copied as appropriate

