set -xeou pipefail

# optionally change the output directory here
out="../lpc-pirate"


# for each body type (sex), create full spritesheets (with
# `lpctools arrange distribute`) and recolors (with 
# `lpctools colors recolor`).

# note: some assets were created only for the male base, those are arranged 
# and/or recolored below this loop. 
for sex in "male" "female"; do

	echo $sex

	# accessories
	# -----------

	lpctools arrange distribute \
	--offsets "accessories/reference_points_${sex}.png" --masks "accessories/masks_${sex}.png" \
	--input accessories/cravat       --output "accessories/_intermediate/cravat/${sex}.png" \
	--input accessories/jabot        --output "accessories/_intermediate/jabot/${sex}.png" \
	--input accessories/sash         --output "accessories/_intermediate/sash/${sex}.png" \
	--input accessories/sash_narrow  --output "accessories/_intermediate/sash_narrow/${sex}.png" \
	--input accessories/belt_leather --output "accessories/_intermediate/belt_leather/${sex}.png" \
	--input accessories/belt_double  --output "accessories/_intermediate/belt_double/${sex}.png" \
	--input accessories/belt_loose   --output "accessories/_intermediate/belt_loose/${sex}.png" \

	# in the process of building the assets, I used these intermediate commands to assemble the 
	# laced shirt and vest items, but then I did some manual editing of the resulting full sheets
	# afterwards. 
	# lpctools arrange distribute \
	# --offsets "accessories/reference_points_${sex}.png" --masks "accessories/masks_${sex}.png" \
	# --input accessories/shirt_mask --output "accessories/_intermediate/shirt_mask/${sex}.png" \
	# --input accessories/vest_mask  --output "accessories/_intermediate/vest_mask/${sex}.png"


	# these are more like headwear, so use the hat reference points and masks
	lpctools arrange distribute \
	--offsets "hat/reference_points_${sex}.png" --masks "hat/masks_${sex}.png" \
	--input accessories/earring    --output "${out}/facial/earring/${sex}.png" 


	# recolor neckwear
	lpctools colors recolor \
	--mapping _palettes/lpc-fabric-from-white.json \
	--input accessories/_intermediate/cravat/${sex}.png \
	--input accessories/_intermediate/jabot/${sex}.png \
	--input accessories/_intermediate/sash/${sex}.png \
	--input accessories/_intermediate/sash_narrow/${sex}.png

	# recolor belts
	lpctools colors recolor \
	--mapping _palettes/lpc-fabric-belt.json \
	--input accessories/_intermediate/belt_leather/${sex}.png \
	--input accessories/_intermediate/belt_loose/${sex}.png \
	--input accessories/_intermediate/belt_double/${sex}.png

	# recolor pants
	lpctools colors recolor \
	--mapping _palettes/lpc-fabric-from-red.json \
	--input clothes/pants/male.png \
	--input clothes/pants/female.png \
	--input clothes/pantaloons/male.png \


	# hats
	# ----

	# arrange all hats
	mkdir -p "${out}/hat/pirate"
	lpctools arrange distribute \
	--offsets "hat/reference_points_${sex}.png" --masks "hat/masks_${sex}.png" \
	--input hat/kerchief                        --output "${out}/hat/pirate/kerchief/${sex}.png" \
	--input hat/bandana                         --output "${out}/hat/pirate/bandana/${sex}.png" \
	--input hat/bandana_skull                   --output "${out}/hat/pirate/bandana_skull/${sex}.png" \
	--input hat/tricorne                        --output "${out}/hat/pirate/tricorne/${sex}.png" \
	--input hat/bicorne_athwart                 --output "${out}/hat/pirate/bicorne_athwart/${sex}.png" \
	--input hat/bicorne_athwart_admiral         --output "${out}/hat/pirate/bicorne_athwart_admiral/${sex}.png" \
	--input hat/bicorne_athwart_admiral_cockade --output "${out}/hat/pirate/bicorne_athwart_admiral_cockade/${sex}.png" \
	--input hat/bicorne_athwart_commodore       --output "${out}/hat/pirate/bicorne_athwart_commodore/${sex}.png" \
	--input hat/bicorne_athwart_pirate          --output "${out}/hat/pirate/bicorne_athwart_pirate/${sex}.png" \
	--input hat/bicorne_foreaft                 --output "${out}/hat/pirate/bicorne_foreaft/${sex}.png" \
	--input hat/bicorne_foreaft_commodore       --output "${out}/hat/pirate/bicorne_foreaft_commodore/${sex}.png" \
	--input hat/bonnie                          --output "${out}/hat/pirate/bonnie/${sex}.png" \
	--input hat/bonnie_feather                  --output "${out}/hat/pirate/bonnie_feather/${sex}.png" \
	--input hat/cavalier                        --output "${out}/hat/pirate/cavalier/${sex}.png" \
	--input hat/cavalier_feather                --output "${out}/hat/pirate/cavalier_feather/${sex}.png" \
	--input hat/tricorne                        --output "${out}/hat/pirate/tricorne/${sex}.png" \
	--input hat/tricorne_captain                --output "${out}/hat/pirate/tricorne_captain/${sex}.png" \
	--input hat/tricorne_captain_pirate         --output "${out}/hat/pirate/tricorne_captain_pirate/${sex}.png" \
	--input hat/tricorne_captain_pirate_skull   --output "${out}/hat/pirate/tricorne_captain_pirate_skull/${sex}.png" \
	--input hat/tricorne_lieutenant             --output "${out}/hat/pirate/tricorne_lieutenant/${sex}.png" \
	--input hat/tricorne_stitched               --output "${out}/hat/pirate/tricorne_stitched/${sex}.png" \
	--input hat/tricorne_thatch                 --output "${out}/hat/pirate/tricorne_thatch/${sex}.png"


	# recolor brown hats (no trim)
	lpctools colors recolor \
	--mapping _palettes/lpc-fabric-from-brown.json \
	--input "${out}/hat/head_band_tied/${sex}.png" \
	--input "${out}/hat/pirate/kerchief/${sex}.png" \
	--input "${out}/hat/pirate/bandana/${sex}.png" \
	--input "${out}/hat/pirate/bandana_skull/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_athwart/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_athwart_pirate/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_foreaft/${sex}.png" \
	--input "${out}/hat/pirate/bonnie/${sex}.png" \
	--input "${out}/hat/pirate/bonnie_feather/${sex}.png" \
	--input "${out}/hat/pirate/cavalier/${sex}.png" \
	--input "${out}/hat/pirate/cavalier_feather/${sex}.png" \
	--input "${out}/hat/pirate/tricorne/${sex}.png" \
	--input "${out}/hat/pirate/tricorne_captain_pirate/${sex}.png" \
	--input "${out}/hat/pirate/tricorne_captain_pirate_skull/${sex}.png" \
	--input "${out}/hat/pirate/tricorne_stitched/${sex}.png" \

	# why are there separate brown and black hats? because that's how I drew 
	# them originally. you could convert them all to the brown palette if you 
	# wanted, I was just too lazy.
	# plus for the most part, the black hats had different colored trim. 
	# by passing both the fabric-from-black and trim-hats palette mappings and 
	# using `--combine product`, all combinations of palettes from the two 
	# mappings are produced
 
	# recolor black hats (w/ trim)
	lpctools colors recolor \
	--mapping _palettes/lpc-fabric-from-black.json \
	--mapping _palettes/palettes-trim-hats.json \
	--combine product \
	--input "${out}/hat/pirate/tricorne_thatch/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_athwart_admiral/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_athwart_admiral_cockade/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_athwart_commodore/${sex}.png" \
	--input "${out}/hat/pirate/bicorne_foreaft_commodore/${sex}.png" \
	--input "${out}/hat/pirate/tricorne_captain/${sex}.png" \
	--input "${out}/hat/pirate/tricorne_lieutenant/${sex}.png" \

	# recolor black hats (no trim)
	lpctools colors recolor \
	--mapping _palettes/lpc-fabric-from-black.json \
	--input "${out}/hat/pirate/tricorne_thatch/${sex}.png"


done

# accessories
# -----------

# copy accessories to output directory
mkdir -p "${out}/neck/"
for object in "cravat" "jabot"; do
	cp -r "accessories/_intermediate/${object}"  "${out}/neck/"
done
mkdir -p "${out}/torso/waist/"
for object in "belt_loose" "belt_double" "belt_leather" "sash" "sash_narrow"; do
	cp -r "accessories/_intermediate/${object}"  "${out}/torso/waist/"
done


# shirts and vests recolors
# -------------------------

# these are male-only at present so done outside the big loop above

# recolor shirts
lpctools colors recolor \
--mapping _palettes/lpc-fabric-from-white.json \
--input clothes/longsleeve_laced.png \
--input clothes/sleeveless_laced.png \
--input clothes/sleeveless.png

# recolor vests
lpctools colors recolor \
--mapping _palettes/lpc-fabric-from-red.json \
--input clothes/vest.png \
--input clothes/vest_open.png \
--input clothes/sleeveless_striped.png \

# if you want, you could recolor striped shirts using the --combine product 
# palette trick to generate a ridiculous number of combinations. I decided 
# it was too many, but go with god
# lpctools colors recolor \
# --mapping _palettes/lpc-fabric-from-white.json \
# --mapping _palettes/lpc-fabric-from-red.json \
# --combine product \
# --input clothes/sleeveless_striped.png

# copy to output directory
for style in "pants" "pantaloons"; do
	outfile="${out}/legs/${style}"
	mkdir -p $outfile
	cp -R "clothes/${style}/."   $outfile
done
for style in "vest" "vest_open"; do
	outfile="${out}/torso/clothes/${style}/male"
	mkdir -p $outfile
	cp clothes/$style/*.png $outfile
done
for style in "longsleeve_laced" "sleeveless_laced" "sleeveless" "sleeveless_striped"; do
	outfile="${out}/torso/clothes/${style}/male"
	mkdir -p $outfile
	cp clothes/$style/*.png $outfile
done

# jacket recolors
# ---------------

# these are male-only at present so done outside the big loop above

# recolor jacket trims with the trim palette mapping
lpctools colors recolor \
--mapping _palettes/palettes-trim.json \
--input jacket/trim/frock_collar.png \
--input jacket/trim/frock_lace.png \
--input jacket/trim/frock_lapel.png \
--input jacket/trim/frock_buttons.png \
--input jacket/trim/jacket_cuffs_lace.png \
--input jacket/trim/jacket_epaulets.png 

# recolor jacket fabric parts with the fabric palette mapping
lpctools colors recolor \
--mapping _palettes/lpc-fabric-from-brown.json \
--input jacket/fabric/jacket_mantal.png \
--input jacket/fabric/jacket_collared.png \
--input jacket/fabric/jacket_cuffs.png \
--input jacket/fabric/jacket_frock.png \
--input jacket/fabric/jacket_pockets.png 

# copy to output directory:
# trim
outfile="${out}/torso/jackets/trim"
mkdir -p $outfile
cp -r jacket/trim/frock_collar      $outfile
cp -r jacket/trim/frock_lace        $outfile
cp -r jacket/trim/frock_lapel       $outfile
cp -r jacket/trim/frock_buttons     $outfile
cp -r jacket/fabric/jacket_pockets  $outfile

# shoulders
mkdir -p $out/shoulders/{epaulets,mantal}/male
cp -R jacket/trim/jacket_epaulets/. $out/shoulders/epaulets/male
cp -R jacket/fabric/jacket_mantal/. $out/shoulders/mantal/male

# wrists
outfile="$out/wrists"
mkdir -p $outfile/{cuffs,lace}/male
cp -r jacket/trim/jacket_cuffs_lace/. $outfile/lace/male
cp -r jacket/fabric/jacket_cuffs/.    $outfile/cuffs/male

# jackets themselvess
mkdir -p "${out}/torso/jackets/"{collared,frock}"/male"
cp -R jacket/fabric/jacket_collared/. "${out}/torso/jackets/collared/male"
cp -R jacket/fabric/jacket_frock/.    "${out}/torso/jackets/frock/male"
